@@ -10,6 +10,10 @@ class VulnerabilityManagementGateway(metaclass=ABCMeta):
     ):
         "send_vulnerability_management"
 
+    @abstractmethod
+    def get_product_type_service(self, service, dict_args, secret_tool, config_tool):
+        "get_product_type_service"
+
     @abstractmethod
     def get_findings_excepted(
         self, service, dict_args, secret_tool, config_tool
