@@ -19,6 +19,10 @@ from devsecops_engine_tools.engine_core.src.domain.model.gateway.devops_platform
 from devsecops_engine_tools.engine_core.src.domain.model.vulnerability_management import (
     VulnerabilityManagement,
 )
+from devsecops_engine_tools.engine_core.src.domain.model.input_core import InputCore
+from devsecops_engine_tools.engine_core.src.domain.model.level_vulnerability import (
+    LevelVulnerability,
+)
 from devsecops_engine_tools.engine_core.src.domain.model.customs_exceptions import (
     ExceptionVulnerabilityManagement,
     ExceptionFindingsExcepted,
@@ -52,6 +56,37 @@ class HandleScan:
         self.secrets_manager_gateway = secrets_manager_gateway
         self.devops_platform_gateway = devops_platform_gateway
 
+    def _define_threshold_quality_vuln(
+        self, input_core: InputCore, dict_args, secret_tool, config_tool
+    ):
+        quality_vulnerability_management = (
+            input_core.threshold_defined.quality_vulnerability_management
+        )
+        if quality_vulnerability_management:
+            product_type = self.vulnerability_management.get_product_type_service(
+                input_core.scope_pipeline, dict_args, secret_tool, config_tool
+            )
+            if product_type:
+                pt_name = product_type.name
+                apply_qualitypt = next(
+                    filter(
+                        lambda qapt: pt_name in qapt,
+                        quality_vulnerability_management["PTS"],
+                    ),
+                    None,
+                )
+                if apply_qualitypt:
+                    pt_info = apply_qualitypt[pt_name]
+                    pt_profile = pt_info["PROFILE"]
+                    pt_apps = pt_info["APPS"]
+
+                    input_core.threshold_defined.vulnerability = (
+                        LevelVulnerability(quality_vulnerability_management[pt_profile])
+                        if pt_apps == "ALL"
+                        or any(map(lambda pd: pd in input_core.scope_pipeline, pt_apps))
+                        else input_core.threshold_defined.vulnerability
+                    )
+
     def _use_vulnerability_management(
         self, config_tool, input_core, dict_args, secret_tool, env
     ):
@@ -72,9 +107,14 @@ class HandleScan:
                     self.devops_platform_gateway.get_variable("build_id"),
                     self.devops_platform_gateway.get_variable("branch_tag"),
                     self.devops_platform_gateway.get_variable("commit_hash"),
-                    env
+                    env,
                 )
             )
+
+            self._define_threshold_quality_vuln(
+                input_core, dict_args, secret_tool, config_tool
+            )
+
         except ExceptionVulnerabilityManagement as ex1:
             logger.error(str(ex1))
         try:
@@ -92,23 +132,33 @@ class HandleScan:
     def process(self, dict_args: any, config_tool: any):
         secret_tool = None
         env = define_env(
-                    self.devops_platform_gateway.get_variable("environment"),
-                    self.devops_platform_gateway.get_variable("branch_name"),
-                )
+            self.devops_platform_gateway.get_variable("environment"),
+            self.devops_platform_gateway.get_variable("branch_name"),
+        )
         if dict_args["use_secrets_manager"] == "true":
             secret_tool = self.secrets_manager_gateway.get_secret(config_tool)
         if "engine_iac" in dict_args["tool"]:
             findings_list, input_core = runner_engine_iac(
-                dict_args, config_tool["ENGINE_IAC"]["TOOL"], secret_tool,self.devops_platform_gateway, env
+                dict_args,
+                config_tool["ENGINE_IAC"]["TOOL"],
+                secret_tool,
+                self.devops_platform_gateway,
+                env,
             )
-            if dict_args["use_vulnerability_management"] == "true" and input_core.path_file_results:
+            if (
+                dict_args["use_vulnerability_management"] == "true"
+                and input_core.path_file_results
+            ):
                 self._use_vulnerability_management(
                     config_tool, input_core, dict_args, secret_tool, env
                 )
             return findings_list, input_core
         elif "engine_container" in dict_args["tool"]:
             findings_list, input_core = runner_engine_container(
-                dict_args, config_tool["ENGINE_CONTAINER"]["TOOL"], secret_tool, self.devops_platform_gateway
+                dict_args,
+                config_tool["ENGINE_CONTAINER"]["TOOL"],
+                secret_tool,
+                self.devops_platform_gateway,
             )
             if (
                 dict_args["use_vulnerability_management"] == "true"
@@ -122,7 +172,9 @@ class HandleScan:
             print(MESSAGE_ENABLED)
         elif "engine_code" in dict_args["tool"]:
             findings_list, input_core = runner_engine_code(
-                dict_args, config_tool["ENGINE_CODE"]["TOOL"], self.devops_platform_gateway
+                dict_args,
+                config_tool["ENGINE_CODE"]["TOOL"],
+                self.devops_platform_gateway,
             )
             if (
                 dict_args["use_vulnerability_management"] == "true"
@@ -159,4 +211,4 @@ class HandleScan:
                 self._use_vulnerability_management(
                     config_tool, input_core, dict_args, secret_tool, env
                 )
-            return findings_list, input_core
\ No newline at end of file
+            return findings_list, input_core
